@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1757 2025/10/18 16:57:00 sthen Exp $
+# $OpenBSD: Quirks.pm,v 1.1758 2025/10/23 19:43:31 sthen Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -510,154 +510,6 @@ sub setup_obsolete_reason
 # want to put regexps as well in there (see the terraform or hs entries
 # for instance)
 setup_obsolete_reason(
-# 6.9
-	3 => 'py-notify',
-	3 => 'glimpse',
-	3 => 'py-metlog',
-	3 => 'pdfmod',
-	5 => 'hyena',
-	5 => 'mono-taglib',
-	3 => 'spatialite_gis',
-	3 => 'librewms',
-	3 => 'libgaiagraphics',
-	3 => 'librasterlite',
-	5 => 'dbus-sharp',
-	5 => 'dbus-sharp-glib',
-	5 => 'mono-gdata',
-	5 => 'mono-notify',
-	5 => 'ndesk-dbus',
-	5 => 'ndesk-dbus-glib',
-	5 => 'mono-xsp',
-	3 => 'py-Numeric',
-	3 => 'k3dsurf',
-	3 => 'spacehulk',
-	3 => 'taxipilot',
-	3 => 'pympd',
-	5 => 'py-vte',
-	5 => 'vte',
-	6 => 'keybinder',
-	3 => 'vinagre',
-	5 => 'gnome-getting-started-docs',
-	3 => 'py-poppler',
-	3 => 'pdfshuffler',
-	27 => 'colord-gtk',
-	3 => 'zeya',
-	3 => 'py-trollius',
-	3 => qr{^kde-i18n-},
-	3 => 'kde-shared-data',
-	3 => 'kde3-langlist',
-	3 => 'kde3-locale',
-	3 => 'kde3-locale-en_US',
-	3 => 'kdeaccessibility',
-	3 => 'kdebase',
-	3 => 'kdegames',
-	3 => 'kdelibs',
-	3 => 'kdesamba',
-	3 => 'qt3-examples',
-	3 => 'qt3-html',
-	3 => 'qt3-mt',
-	3 => 'qt3-mysql',
-	3 => 'qt3-postgresql',
-	3 => 'qt3-sqlite2',
-	6 => 'gtk3mm-documentation',
-	5 => 'libxml++3',
-	3 => 'xfce4-statusnotifier',
-	3 => 'pylint3-gui',
-	3 => 'e_dbus',
-	3 => 'ecore',
-	3 => 'edje',
-	3 => 'eet',
-	3 => 'efreet',
-	3 => 'eina',
-	3 => 'eio',
-	3 => 'elementary',
-	3 => 'embryo',
-	3 => 'emotion',
-	3 => 'enlightenment',
-	3 => 'ethumb',
-	3 => 'evas',
-	3 => 'qtstyleplugins',
-	0 => 'p5-Regexp-Copy',
-	28 => 'mcollective-puppet-agent',
-	3 => 'kdepim-apps-libs',
-	29 => 'gns3',
-	3 => 'py-qt4',
-	3 => 'py-qt4-docs',
-	29 => 'hitch',
-	3 => 'xtraceroute',
-	13 => 'py-vorbis',
-	13 => 'py-ogg',
-	3 => 'sattrack',
-	3 => 'packit',
-	3 => 'nemesis',
-	6 => 'lxnb',
-	3 => 'siphon',
-	6 => 'avinfo',
-	0 => 'xfed',
-	36 => 'www6to4',
-	3 => 'gimmix',
-	3 => 'xhippo',
-	0 => 'hnb',
-	38 => 'icinga',
-	38 => 'icinga-web',
-	38 => 'icinga-cgi',
-	38 => 'icinga-idoutils',
-	3 => 'swftools',
-	3 => 'swfmill',
-	3 => 'ming',
-	3 => 'quvi',
-	3 => 'libquvi',
-	3 => 'libquvi-scripts',
-	6 => 'cclive',
-	4 => 'viz',
-	40 => 'driftnet',
-	6 => 'enjoympeg',
-	6 => 'trac-ldapplugin',
-	0 => 'xboing',
-	3 => 'beaver',
-	3 => 'tracnav',
-	3 => 'flasm',
-	13 => 'mpd-add-similar',
-	13 => 'py-mpd',
-	3 => 'abs',
-	3 => 'arena',
-	3 => 'teagtk',
-	5 => 'tempwatch',
-	29 => 'avenger',
-	41 => 'mk',
-	1 => 'sabredav',
-	3 => 'mollify',
-	3 => 'seyon',
-	6 => 'mingw',
-	3 => 'bsd-airtools',
-	3 => 'gtkpod',
-	0 => 'golem',
-	3 => 'wmmultipop3',
-	3 => 'wmpop3',
-	3 => 'angst',
-	3 => 'audiopreview',
-	3 => 'pcsxr',
-	41 => 'libbio',
-	41 => 'libfmt',
-	41 => 'libregexp9',
-	41 => 'libutf',
-	5 => qr{^hs-},
-	6 => 'gstreamer',
-	6 => 'gstreamer-ffmpeg',
-	6 => 'gstreamer-plugins-bad',
-	6 => 'gstreamer-plugins-base',
-	6 => 'gstreamer-plugins-gl',
-	6 => 'gstreamer-plugins-good',
-	6 => 'gstreamer-plugins-ugly',
-	29 => 'lives',
-	5 => 'py-wsgiproxy',
-	5 => 'py-sqlite',
-	43 => 'upt',
-	43 => 'upt-cpan',
-	43 => 'upt-openbsd',
-	43 => 'upt-pypi',
-	43 => 'upt-rubygems',
-	3 => 'p5-VCP-autrijus',
 # 7.0
 	3 => qr{^ruby26-},
 	3 => 'mailpile',
@@ -1153,6 +1005,7 @@ setup_obsolete_reason(
 	5 => 'pygame_sdl2',
 	3 => 'dynagen',
 	3 => 'termshark',
+	14 => 'py3-lief',
 );
 
 # though it's not yet used, these should be pkgnames, so that eventually
@@ -1167,8 +1020,6 @@ my $obsolete_suggestion = {
 	'gbirthday' => 'qbirthday',
 	'qlandkartegt' => 'qmapshack',
 	'keepassx' => 'keepassxc',
-	'lives' => [qw(kdenlive shotcut)],
-	'pdfshuffler' => 'pdfarranger',
 	'gotweb' => 'gotwebd',
 	'compton' => 'picom',
 	'exa' => 'eza',
@@ -1180,7 +1031,6 @@ my $obsolete_message = {
 	1 => "no benefit to being packaged",
 	2 => "no longer maintained and full of security holes",
 	3 => "no longer maintained upstream",
-	4 => "superseded by base component",
 	5 => "outdated and/or no longer required by other ports",
 	6 => "no longer useful",
 	7 => "removed in favor of using the language's package manager",
@@ -1190,15 +1040,9 @@ my $obsolete_message = {
 	11 => "no longer packageable",
 	12 => "use the alternative plugin distributed with roundcube instead (markasjunk, managesieve)",
 	13 => "has a dependency on obsolete software",
+	14 => "port needs updating",
 	15 => "use rspamd's internal milter support instead",
-	27 => "requires GUdev",
-	28 => "consider migrating MCollective agents and filters using tools like Bolt and PuppetDB's Puppet Query Language",
 	29 => "unmaintained port that was blocking other changes in ports",
-	36 => "ancient software, use pf.conf(5) 'af-to'",
-	38 => "icinga 1 is end-of-life, migrate to icinga 2 (needs config rewrite)",
-	40 => "ancient software that often crashes and relies on single HTTP (no TLS) connections, use wireshark",
-	41 => "upstream moved to unversioned tarballs, use the plan9port (same upstream) package instead",
-	43 => "using portgen instead is recommended",
 	44 => "qucs-s Qt4 UI not working correctly, suggest xschem or kicad's eeschema instead",
 	45 => "crashes in many different ways at runtime",
 	46 => "moved to binary bootstraps",
